==> mongodb-ui-components-4.2.5.tgz: package/src/footer/index.js <==
import {h} from 'preact'
import LanguagePicker from './language-picker'
import Form from './form'
import sections from './sections'
import icons from './icons'

const style = (props) => ({
  backgroundColor: props.bg || '#1A1A1A',
  color: props.color || '#fff'
})

const List = ({title, items, maxWidth, hasIcons}) => (
  <div class={`w-${maxWidth} full-if-lt-900 m-20`}>
    <small><strong>{title}</strong></small>
    <ul>{items.map(([href, text, isTarget]) =>
      <li class='m-v-10'>
        <a
          href={href}
          class='no-decor hover-underline'
          target={isTarget ? '_BLANK' : null}>
          <div class='fl fl-center-y'>
            {hasIcons ? icons[text] : null}
            <small>{text}</small>
          </div>
        </a>
      </li>
    )}</ul>
  </div>
)

export default (props) => (
  <footer style={style(props)} class='p-v-30 w-full'>
    <div class='w-max-1200 w-full m-auto'>
      <div class='fl fl-justify-between fl-wrap'>
        {sections.map(List)}
      </div>

      <div
        class='m-auto'
        style={{borderBottom: '1px solid white', width: 'calc(100% - 40px)'}} />

      <div class='m-h-20 m-v-30 fl fl-wrap fl-justify-between'>
        <LanguagePicker visible={props.hide !== true} languages={props.languages} />
        <Form />
      </div>

      <div class='m-20 w-max-600'>
        <small>
          © 2018 MongoDB, Inc.<br />
          Mongo, MongoDB, and the MongoDB leaf logo are registered trademarks of MongoDB, Inc.
        </small>
      </div>
    </div>
  </footer>
)

==> mongodb-ui-components-4.2.16.tgz: package/src/footer/index.js <==
import {h} from 'preact'
import LanguagePicker from './language-picker'
import Form from './form'
import sections from './sections'
import icons, {mongoLeaf} from './icons'

const style = ({bg, color}) => ({
  backgroundColor: bg || '#1A1A1A',
  color: color || '#fff'
})

const copyright = (
  <div class='w-max-600 fl fl-center-y'>
    {mongoLeaf}
    <small class='m-l-10'>
      © 2018 MongoDB, Inc.<br />
      Mongo, MongoDB, and the MongoDB leaf logo are registered trademarks of MongoDB, Inc.
    </small>
  </div>
)

const List = ({title, items, maxWidth, hasIcons}) => (
  <div class={`w-${maxWidth} full-if-lt-900 m-20`}>
    <small><strong>{title}</strong></small>
    <ul>{items.map(([href, text, isTarget]) =>
      <li class='m-v-10'>
        <a
          href={href}
          class='no-decor hover-underline'
          target={isTarget ? '_BLANK' : null}>
          <div class='fl fl-center-y'>
            {hasIcons ? icons[text] : null}
            <small>{text}</small>
          </div>
        </a>
      </li>
    )}</ul>
  </div>
)

export default (props) => (
  <footer style={style(props)} class='p-v-30 w-full'>
    <div class='w-max-1200 w-full m-auto'>
      <div class='fl fl-justify-between fl-wrap'>
        {sections.map(List)}
      </div>

      <div
        class='m-auto'
        style={{borderBottom: '1px solid white', width: 'calc(100% - 40px)'}} />

      <div class='m-h-20 m-v-30 fl fl-wrap fl-justify-between'>
        <div>
          <div class='w-max-80'>
            <LanguagePicker visible={props.hideLanguagePicker !== true} languages={props.languages} />
          </div>
          <span class='hide-lt-910'>
            {copyright}
          </span>
        </div>
        <Form />
      </div>

      <div class='m-20 hide-gt-910'>
        {copyright}
      </div>
    </div>
  </footer>
)
